mix vibe_kit.install (vibe_kit v0.1.2)

Copy Markdown View Source

Installs Elixir Vibe project conventions

Adds the shared mix ci alias, preferred Mix CLI environment, and quality tooling dependencies used across Elixir Vibe projects.

Example

mix igniter.install vibe_kit

Options

  • --no-reach - skip Reach and reach.check --arch --smells
  • --no-strict-clones - run ExDNA as ex_dna instead of ex_dna --max-clones 0
  • --no-ex-slop - skip ExSlop and .credo.exs plugin setup
  • --agents-md - create AGENTS.md with project instructions
  • --claude-md - create CLAUDE.md with project instructions